@@ -3,13 +3,14 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Writer::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Writer::VERSION = '2.0900'; # TRIAL
+  $Moose::Meta::Method::Accessor::Native::Writer::VERSION = '2.0901'; # TRIAL
 }
 
 use strict;
 use warnings;
 
 use List::MoreUtils qw( any );
+use Moose::Util;
 
 use Moose::Role;
 
@@ -85,18 +86,26 @@ sub _constraint_must_be_checked {
     my $attr = $self->associated_attribute;
 
     return $attr->has_type_constraint
-        && (!$self->_is_root_type( $attr->type_constraint )
-         || ( $attr->should_coerce && $attr->type_constraint->has_coercion)
-           );
+        && ( !$self->_is_root_type( $attr->type_constraint )
+        || ( $attr->should_coerce && $attr->type_constraint->has_coercion ) );
 }
 
 sub _is_root_type {
     my $self = shift;
-    my ($type) = @_;
+    my $type = shift;
 
-    my $name = $type->name;
-
-    return any { $name eq $_ } @{ $self->root_types };
+    if (
+        Moose::Util::does_role( $type, 'Specio::Constraint::Role::Interface' ) )
+    {
+        require Specio::Library::Builtins;
+        return
+            any { $type->is_same_type_as( Specio::Library::Builtins::t($_) ) }
+        @{ $self->root_types };
+    }
+    else {
+        my $name = $type->name;
+        return any { $name eq $_ } @{ $self->root_types };
+    }
 }
 
 sub _inline_copy_native_value {
